package biz.capitalware.mqfm.action.objects;

import java.io.File;
import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the Delete action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class DeleteObject extends FMFileObject
{
   public String  filenames[] = null;

   /**
    * The constructor
    */
   public DeleteObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      for (int i=0; i < filenames.length; i++)
         filenames[i] = Tokens.replace(filenames[i], MQFM.userProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (filenames == null)
         throw new IllegalArgumentException("Error: You must specify a filename for the Delete action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     FileName             = " + filenames[0]);
      for (int i=1; i < filenames.length; i++)
         MQFM.logger.info("                            " + filenames[i]);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+Constants.DELETE_ELEMENT+">"+LINE_SEPARATOR);
      
      for (int i=0; i < filenames.length; i++)
      {
         if (filenames[i].indexOf(File.separator) != -1 )
         {
            int x = filenames[i].lastIndexOf(File.separator);

            String dir   = filenames[i].substring(0, x);
            String fname = filenames[i].substring(x+1);

            al.add("  <"+Constants.FILE_ELEMENT+" "+Constants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+Constants.FILE_ELEMENT+">"+LINE_SEPARATOR);
         }
         else
            al.add("  <"+Constants.FILE_ELEMENT+">"+filenames[i]+"</"+Constants.FILE_ELEMENT+">"+LINE_SEPARATOR);
      }
      
      al.add("</"+Constants.DELETE_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
}
