package biz.capitalware.mqfm.action.objects;

import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the If action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ElseObject extends FMObject
{
   public int                 exitRC = 0;
   public ArrayList<FMObject> actionAL = null;
   
   /**
    * The constructor
    */
   public ElseObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (exitRC < 0)
         throw new IllegalArgumentException("Error: The exitrc attribute must be greater than 0.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     exitrc               = " + exitRC);
      
      if (actionAL != null)
      {
         MQFM.logger.info("     Else Action Names:");
         for (int i=0; i < actionAL.size(); i++)
         {
            FMObject fmo = actionAL.get(i);
            MQFM.logger.info("       Action             = " + fmo.actionName);
         }
      }
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+Constants.ELSE_ELEMENT+" "+Constants.EXIT_RC_ATTRIBUTE+"=\""+exitRC+"\">"+LINE_SEPARATOR);

      /*
       * Add info from actions
       */
      if (actionAL != null)
      {
         for (int i=0; i < actionAL.size(); i++)
         {
            FMObject fmo = (FMObject)actionAL.get(i);
            ArrayList<String> actionAL = fmo.toStringArray();
            for (int j=0; j < actionAL.size(); j++)
            {
               al.add("  "+actionAL.get(j));
            }
         }
      }
      
      al.add("</"+Constants.ELSE_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
}
