package biz.capitalware.mqfm.action.objects;

import java.util.ArrayList;

/**
 * This is an abstract class for MQ File Mover objects.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public abstract class FMObject implements Cloneable
{
   protected static final String LINE_SEPARATOR = System.getProperty("line.separator");
   
   public      String   labelName   = "default";
   public      String   actionName  = null;
   public      boolean  onErrorFail = true;

   /**
    * The constructor
    */
   public FMObject()
   {
      super();

      /* Set action name. */
      int x = this.getClass().getName().lastIndexOf(".");
      int y = this.getClass().getName().lastIndexOf("Object");
      if (x != -1)
         this.actionName = this.getClass().getName().substring(x+1, y);
      else
         this.actionName = this.getClass().getName().substring(0, y);
   }
   
   /**
    * Clone the object
    */
   public Object clone()
   {
      try
      {
         return super.clone();
      }
      catch (CloneNotSupportedException e)
      {
         return null;
      }
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public String toStringForFile()
   {
      StringBuffer action = new StringBuffer();
      ArrayList<String> al = toStringArray();

      for (int i=0; i < al.size(); i++)
         action.append("    "+al.get(i));
      
      return action.toString();
   }

   public abstract void performTokenization();

   public abstract void checkObject();

   public abstract void printValues();

   public abstract ArrayList<String> toStringArray();
}
