package biz.capitalware.mqfm.action.objects;

import java.io.File;
import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the Merge action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MergeObject extends FMFileObject
{
   public String     srcFilenames[] = null;
   public String     toFilename = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public MergeObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (toFilename != null)
         toFilename = Tokens.replace(toFilename, MQFM.userProperties);
      
      for (int i=0; i < srcFilenames.length; i++)
         srcFilenames[i] = Tokens.replace(srcFilenames[i], MQFM.userProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      String targetDir = null;
      if (toFilename.indexOf(File.separator) != -1)
         targetDir = toFilename.substring(0,toFilename.lastIndexOf(File.separator));

      /* Do we need to create the directory? */
      if (targetDir != null)
      {
         if (createDir)
         {
            if (!(new File(targetDir).exists()))
            {
               if ((new File(targetDir)).mkdirs())
                  MQFM.logger.info("Successfully created directory: " + targetDir);
               else
                  throw new IllegalArgumentException("Error: Cannot create directory: " + targetDir);
            }
         }
         else if (!(new File(targetDir).exists()))
            throw new IllegalArgumentException("Target directory '"+targetDir+"' does not exit.");
      }
      
      if (srcFilenames == null)
         throw new IllegalArgumentException("Error: You must specify at least one source FileName for the Merge action.");

      if (toFilename == null)
         throw new IllegalArgumentException("Error: You must specify a ToFileName for the Merge action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     Source File Names    = " + srcFilenames[0]);
      for (int i=1; i < srcFilenames.length; i++)
         MQFM.logger.info("                            " + srcFilenames[i]);
      
      MQFM.logger.info("     To FileName          = " + toFilename);
      MQFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      al.add("<"+Constants.MERGE_ELEMENT+" "+Constants.FILE_ATTRIBUTE+"=\""+toFilename+">"+LINE_SEPARATOR);
      
      for (int i=0; i < srcFilenames.length; i++)
      {
         if (srcFilenames[i].indexOf(File.separator) != -1 )
         {
            int x = srcFilenames[i].lastIndexOf(File.separator);

            String dir   = srcFilenames[i].substring(0, x);
            String fname = srcFilenames[i].substring(x+1);

            al.add("  <"+Constants.FILE_ELEMENT+" "+Constants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+Constants.FILE_ELEMENT+">"+LINE_SEPARATOR);
         }
         else
            al.add("  <"+Constants.FILE_ELEMENT+">"+srcFilenames[i]+"</"+Constants.FILE_ELEMENT+">"+LINE_SEPARATOR);
      }
      
      al.add("</"+Constants.MERGE_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
}
