package biz.capitalware.mqfm.action.objects;

import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the Sleep action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SleepObject extends FMObject
{
   public int     milliseconds = 0;
   public int     seconds = 0;
   public int     minutes = 0;
   public int     hours = 0;

   /**
    * The constructor
    */
   public SleepObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if ( (milliseconds < 0) || (milliseconds > 59) )
         throw new IllegalArgumentException("Error: The milliseconds value is invalid. Use a number between 0 and 59.");

      if ( (seconds < 0) || (seconds > 59) )
         throw new IllegalArgumentException("Error: The seconds value is invalid. Use a number between 0 and 59.");
      
      if ( (minutes < 0) || (minutes > 59) )
         throw new IllegalArgumentException("Error: The minutes value is invalid. Use a number between 0 and 59.");

      if ( (hours < 0) || (hours > 23) )
         throw new IllegalArgumentException("Error: The hours value is invalid. Use a number between 0 and 23.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     Hours                = " + hours);
      MQFM.logger.info("     Minutes              = " + minutes);
      MQFM.logger.info("     Seconds              = " + seconds);
      MQFM.logger.info("     MilliSeconds         = " + milliseconds);
   }

   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();

      String attributes = "";
      
      if (hours != 0)
         attributes += ""+Constants.HOURS_ATTRIBUTE+"=\"" + hours + "\" ";
      
      if (minutes != 0)
         attributes += ""+Constants.MINUTES_ATTRIBUTE+"=\"" + minutes + "\" ";
      
      if (seconds != 0)
         attributes += ""+Constants.SECONDS_ATTRIBUTE+"=\"" + seconds + "\" ";
      
      if (milliseconds != 0)
         attributes += ""+Constants.MILLISECONDS_ATTRIBUTE+"=\"" + milliseconds + "\" ";
      
      al.add("<"+Constants.SLEEP_ELEMENT+"" + attributes + "/>"+LINE_SEPARATOR);
      
      return al;
   }
}
