package biz.capitalware.mqfm.actions;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

import javax.crypto.NoSuchPaddingException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.EncryptFileObject;
import biz.capitalware.mqfm.handlers.AES;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;

/**
 * This class will handle the EncryptFile action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class EncryptFileAction extends FMAction
{
   private EncryptFileObject   efo;

   /**
    * The constructor
    * @param efo
    * @param logger
    */
   public EncryptFileAction(EncryptFileObject efo)
   {
      super(efo.actionName);
      this.efo = efo;
   }

   /**
    * Perform the sort work.
    */
   public int doWork()
   {
      int exitCode = 0;
      efo.printValues();

      String toPathAndFilename = Tokens.replace(efo.actionName, efo.toFilename, IO.getFileName(efo.srcFilename), 1, MQFM.userProperties);
      
      try
      {
         AES aes = new AES(efo.crypto.passPhrase, efo.crypto.keySize);
         aes.encrypt(new FileInputStream(efo.srcFilename), new FileOutputStream(toPathAndFilename));
         efo.fileCount++;
         
         MQFM.logger.info("Successfully encrypted '" + efo.srcFilename + "' to file '" + toPathAndFilename + "'");
      }
      catch (InvalidKeyException e)
      {
         MQFM.logger.fatal("InvalidKeyException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (NoSuchAlgorithmException e)
      {
         MQFM.logger.fatal("NoSuchAlgorithmException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (NoSuchPaddingException e)
      {
         MQFM.logger.fatal("NoSuchPaddingException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (InvalidAlgorithmParameterException e)
      {
         MQFM.logger.fatal("InvalidAlgorithmParameterException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (UnsupportedEncodingException e)
      {
         MQFM.logger.fatal("UnsupportedEncodingException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (FileNotFoundException e)
      {
         MQFM.logger.fatal("FileNotFoundException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }

      if (!efo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
