package biz.capitalware.mqfm.actions;

import java.io.File;
import java.util.Date;

import org.jdom.JDOMException;

import com.ibm.mq.MQException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.ReceiveObject;
import biz.capitalware.mqfm.mq.MQGetMsg;
import biz.capitalware.mqfm.mq.objects.MQObject;
import biz.capitalware.mqfm.objects.MQFMException;

/**
 * This class will handle the receive action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ReceiveAction extends FMAction
{
   private ReceiveObject   ro;
   private MQObject        mq;

   /**
    * The constructor
    * @param ro
    * @param logger
    */
   public ReceiveAction(ReceiveObject ro)
   {
      super(ro.actionName);
      this.ro = ro;
   }

   /**
    * Perform the receive work.
    */
   public int doWork()
   {
      int exitCode = 0;
      MQGetMsg mqh = null;
      ro.printValues();
      
      try
      {
         mq = new MQObject(ro.qMgrName, ro.qObject, ro.mqXMLFile, ro.CCDTFile);
         mq.checkQM();

         mq.DumpUserParms();

         mqh = new MQGetMsg(mq);

         Runtime.getRuntime().addShutdownHook(new ShutdownThread(mqh));

         mqh.connect();

         exitCode = mqh.retrieveMsg(ro);
      }
      catch (JDOMException e)
      {
         MQFM.logger.fatal("JDOMException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (MQException e)
      {
         MQFM.logger.fatal("MQException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal("MQException: " + e.getCause());
         MQFM.logger.fatal("MQCC=" + e.completionCode + " : MQRC="+e.reasonCode);
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (MQFMException e)
      {
         MQFM.logger.fatal("MQFMException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (Exception e)
      {
         MQFM.logger.fatal("Exception: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      finally
      {
         if ( mqh != null)
            mqh.disconnect();
      }
      
      if (!ro.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }

   /**
    * This class will handle the shutdown.
    *
    */
   private static class ShutdownThread extends Thread
   {
      private MQGetMsg  mqh;

      /**
       * The constructor
       * @param mqh
       */
      public ShutdownThread(MQGetMsg mqh)
      {
         this.mqh = mqh;
      }

      /**
       * Do the work.
       */
      public void run()
      {
         MQFM.logger.info("ReceiveAction: Shutdown requested at " + new Date());

         mqh.stopIt();
      }
   }
}
