package biz.capitalware.mqfm.actions;

import java.io.IOException;
import java.util.Date;

import org.jdom.JDOMException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.ScheduleObject;
import biz.capitalware.mqfm.objects.Constants;
import biz.capitalware.mqfm.objects.PastDateException;
import biz.capitalware.mqfm.schedule.ScheduleEntry;
import biz.capitalware.mqfm.schedule.ScheduleManager;
import biz.capitalware.mqfm.schedule.Schedule;
import biz.capitalware.mqfm.schedule.ScheduleEventListener;
import biz.capitalware.mqfm.xml.ScheduleXml;

/**
 * This class will handle executing an action command at a specific time.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ScheduleAction extends FMAction
{
   private ScheduleObject   so;
   
   public ScheduleAction(ScheduleObject so)
   {
      super(so.actionName);
      this.so = so;
   }

   /**
    * Perform schedule work.
    */
   public int doWork()
   {
      Schedule[] schedules = null; 
      Schedule oneSchedule = null;
      int exitCode = 0;
      Thread currentThread = null;
      java.text.DecimalFormat df0 = new java.text.DecimalFormat("0000");
      String schName; 
      
      so.printValues();

      ScheduleManager em = new ScheduleManager();

      ScheduleXml sxh = new ScheduleXml();
      try
      {
         sxh.readXMLFile(so.xmlFile);
         schedules = sxh.getSchedules(); 

         for (int i=0; i < schedules.length; i++)
         {
            oneSchedule = schedules[i];
            
            schName = "Schedule_"+df0.format(i+1);
            MQFM.logger.info("Schedule Action: " + schName);
            oneSchedule.printValues();
            oneSchedule.checkObject();
            
            em.addSchedule(schName, 
                           oneSchedule.minutes, 
                           oneSchedule.hours, 
                           oneSchedule.daysOfMonth, 
                           oneSchedule.months, 
                           oneSchedule.daysOfWeek, 
                           oneSchedule.year,
                           oneSchedule.xmlFile,
                           new ScheduleEventListener() 
            {
               public void handleEvent(ScheduleEntry entry)
               {
                  MQFM.logger.info("Schedule Action is starting: "+entry.getName()+" [" + entry.getFile()+"]");

                  MQFM fm = new MQFM();
                  fm.setXmlFilename(entry.getFile());
                  fm.doWork(Constants.ONE_PASS, false);
               }
             });
         }
      }
      catch (PastDateException e)
      {
         MQFM.logger.fatal("PastDateException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      catch (JDOMException e)
      {
         MQFM.logger.fatal("JDOMException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }

      currentThread = Thread.currentThread();
      Runtime.getRuntime().addShutdownHook(new ShutdownThread(currentThread));

      // do your work until the thread is interrupted
      try
      {
         while (!currentThread.isInterrupted())
         {
            Thread.sleep(1000);
         }
      }
      catch (InterruptedException e)
      {
         MQFM.logger.info("Watch wait loop was interrupted.");
      }

      MQFM.logger.info("Beginning cleanup to exit.");

      if (!so.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }

   /**
    * This class will handle the shutdown.
    *
    */
   private static class ShutdownThread extends Thread
   {
      private Thread workerThread;

      /**
       * The constructor
       * @param workerThread
       * @param logger
       */
      public ShutdownThread(Thread workerThread)
      {
         this.workerThread = workerThread;
      }

      /**
       * Do the work.
       */
      public void run()
      {
         MQFM.logger.info("ScheduleAction: shutdown requested at " + new Date());

         // request worker thread to finish
         workerThread.interrupt();

         // wait for the worker thread to finish
         try
         {
            synchronized (workerThread)
            {
               workerThread.wait();
            }
         }
         catch (InterruptedException e)
         {}
         MQFM.logger.info("ScheduleAction: shutdown at " + new Date());
      }
   }
}
