package biz.capitalware.mqfm.actions;

import java.io.IOException;

import com.ice.tar.Tar;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.TarObject;
import biz.capitalware.mqfm.handlers.Tokens;

/**
 * This class will handle the Tar action.
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class TarAction extends FMAction
{
   private TarObject to;

   /**
    * The constructor
    * 
    * @param to
    * @param logger
    */
   public TarAction(TarObject to)
   {
      super(to.actionName);
      this.to = to;
   }

   /**
    * Perform the tar work.
    */
   public int doWork()
   {
      int exitCode = 0;
      to.printValues();

      to.tarFilename = Tokens.replace(to.actionName, to.tarFilename, to.srcFilename, 1, MQFM.userProperties);

      try
      {
         Tar.createTar(to.srcFilename , to.tarFilename);
         to.fileCount++;

         MQFM.logger.info("Successfully created archive '" + to.tarFilename + "' from '" + to.srcFilename + "'");
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         
         if (to.onErrorFail)
            exitCode = 8;
      }

      return exitCode;
   }
}
