package biz.capitalware.mqfm.handlers;

import java.util.Comparator;

import biz.capitalware.mqfm.action.objects.MergeSortObject;
import biz.capitalware.mqfm.action.objects.SortObject;

/**
 * This class will handle the comparing of 2 strings.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ExternalSortComparator implements Comparator<String>
{
   protected int           column = 1;
   protected char          order = 'A';

   /**
    * The constructor
    * @param so
    * @param logger
    */
   public ExternalSortComparator(SortObject so)
   {
      super();
      
      this.column = so.column;
      this.order = so.order;
   }

   /**
    * The constructor
    * @param mso
    * @param logger
    */
   public ExternalSortComparator(MergeSortObject mso)
   {
      super();
      
      this.column = mso.column;
      this.order = mso.order;
   }

   /**
    * Compare 2 strings
    * @param r1
    * @param r2
    */
   public int compare(String r1, String r2)
   {
      if (order == 'A')  // ascending order
         return handleCompare(r1, r2);
      else               // descending order
         return (-1 * handleCompare(r1, r2)); // invert the results
   }
   
   /**
    * Compare 2 strings.
    * @param r1
    * @param r2
    * @return
    */
   private int handleCompare(String r1, String r2)
   {
      String n1;
      String n2;
      
      if (column == 1)            
         return r1.compareTo(r2);
      else
      {
         if (column <= r1.length())
            n1 = r1.substring(column-1);
         else
            n1 = "";
         
         if (column <= r2.length())
            n2 = r2.substring(column-1);
         else
            n2 = "";
         
         return n1.compareTo(n2);
      }
   }
}
