package biz.capitalware.mqfm.handlers;

import java.io.File;
import java.io.FilenameFilter;

/**
 * This class will handle retrieving a list of files based on a filter.
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class FilterFiles implements FilenameFilter
{
   private String prefix;
   private String suffix;

   /**
    * The constructor
    * @param fileFilter
    */
   public FilterFiles(String fileFilter)
   {
      super();

      int x = fileFilter.lastIndexOf('*');
      if (x == 0)
      {
         prefix = null;
         suffix = fileFilter.substring(1);
      }
      else if (x == -1)
      {
         prefix = fileFilter;
         suffix = null;
      }
      else if (x == fileFilter.length())
      {
         prefix = fileFilter.substring(0,x);
         suffix = null;
      }
      else
      {
         prefix = fileFilter.substring(0,x);
         suffix = fileFilter.substring(x+1);
      }
   }

   /**
    * Filter the filenames
    *
    * @param dir
    * @param name
    * @return true / false
    */
   public boolean accept(File dir, String name)
   {
      File file = new File(dir, name);
      if (file.isFile())
      {
         if (prefix == null)
         {
            return name.endsWith(suffix);
         }
         else if (suffix == null)
         {
            return name.startsWith(prefix);
         }
         else
         {
            return name.startsWith(prefix) && name.endsWith(suffix);
         }
      }
      return false;
   }
}
