package biz.capitalware.mqfm.mq;

import java.io.IOException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.PutQuitObject;
import biz.capitalware.mqfm.mq.objects.MQObject;
import biz.capitalware.mqfm.objects.Constants;
import biz.capitalware.mqfm.objects.MQFMException;

import com.ibm.mq.*;

/**
 * This class will handle all MQ interactions for File2Msg.
 *
 * @author Roger Lacroix
 * @version 1.3
 * @license Apache 2 License
 */
public class MQPutQuit extends MyMQ
{
   /**
    * The constructor
    */
   public MQPutQuit(MQObject qm)
   {
   	super(qm);
   }

   /**
    * Put a 'QUIT' message to a queue.
    *
    * @param queueName
    * @throws MQFMException 
    */
   public void simplePut1(PutQuitObject  pqo) throws MQFMException
   {
      MQQueue _outQ = null;
      MQPutMessageOptions pmo = new MQPutMessageOptions();
      pmo.options = MQC.MQPMO_FAIL_IF_QUIESCING;

      try
      {
         _outQ = openOutQ(mqo.qObject);

         MQFM.logger.info("Successfully opened queue: " + mqo.qObject);
         MQMessage sendmsg = new MQMessage();

         sendmsg.messageId     = MQC.MQMI_NONE;
         sendmsg.correlationId = MQC.MQCI_NONE;
         sendmsg.feedback      = MQC.MQFB_QUIT;
         sendmsg.format        = MQC.MQFMT_STRING;
         sendmsg.messageType   = MQC.MQMT_DATAGRAM;

         sendmsg.write(Constants.QUIT_MSG.getBytes());

         // put the message on the queue.
         _outQ.put(sendmsg, pmo);

         MQFM.logger.info("Put '"+ Constants.QUIT_MSG +"' message to " + mqo.qObject  );
      }
      catch (MQException e)
      {
         MQFM.logger.fatal("MQException: " + e.getMessage() + " : QName=" + mqo.qObject);
         MQFM.logger.fatal("MQCC=" + e.completionCode + " : MQRC="+e.reasonCode);
         MQFM.globalErrorText = e.getLocalizedMessage();
      }
      catch (IOException ioex)
      {
         MQFM.logger.fatal("IOException: " + ioex.getMessage());
         MQFM.globalErrorText = ioex.getLocalizedMessage();
      }
      finally
      {
         try
         {
            // Done. Close the queue.
            if (_outQ != null)
            {
               _outQ.close();
               MQFM.logger.info("Successfully closed the queue.");
            }
         }
         catch (MQException e)
         {
            MQFM.logger.fatal("MQException: " + e.getMessage() + " : QName=" + mqo.qObject);
            MQFM.logger.fatal("MQCC=" + e.completionCode + " : MQRC="+e.reasonCode);
            MQFM.globalErrorText = e.getLocalizedMessage();
         }
      }
   }
}
