package biz.capitalware.mqfm.other;

import java.net.InetAddress;
import java.util.Collections;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.StringUtilities;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class logs general / common information.
 *
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.2
 * @license Apache 2 License
 */
public class GeneralInfo
{
   /**
    * The constructor - make sure nothing instantiates this class.
    * It must be accessed in a static way.
    */
   private GeneralInfo()
   {}

   /**
    * Dump the header information.
    * @param name
    * @param logger
    */
   public static void DumpHeader()
   {
      MQFM.logger.info("----------------------------------------------------------------------");
      MQFM.logger.info(MQFM.WHO_AM_I + " version " + Constants.VERSION + " is now starting.");

      MQFM.logger.info("System Information:");
      try
      {
         MQFM.logger.info("     JVM                  = " + System.getProperty("java.vendor") + " v"  + System.getProperty("java.version"));
         MQFM.logger.info("     OS                   = " + System.getProperty("os.name"));
         MQFM.logger.info("     user.name            = " + System.getProperty("user.name") );
         MQFM.logger.info("     user.home            = " + System.getProperty("user.home"));
         MQFM.logger.info("     user.dir             = " + System.getProperty("user.dir"));
         MQFM.logger.info("     java.io.tmpdir       = " + System.getProperty("java.io.tmpdir"));
         MQFM.logger.info("     Hostname             = " + InetAddress.getLocalHost().getHostName());
         MQFM.logger.info("     HostAddress          = " + InetAddress.getLocalHost().getHostAddress());
         MQFM.logger.info("     CanonicalHostname    = " + InetAddress.getLocalHost().getCanonicalHostName());
         MQFM.logger.info("     UseFileLocking       = " + MQFM.useFileLocking);
      }
      catch (Exception e)
      {
         MQFM.logger.fatal("Exception: " + e );
      }
   }

   /**
    * Dump the header information.
    * @param name
    * @param logger
    */
   public static void GlobalValues(Hashtable<String,String> userProperties)
   {
      MQFM.logger.info("User Global Values:");
      
      if (!(userProperties.isEmpty()))
      {
         Enumeration<String> keysEnum = userProperties.keys();
         Vector<String> keyList = new Vector<String>();
         while(keysEnum.hasMoreElements())
         {
            String item = (String)keysEnum.nextElement();
            // Do not add hostname or ipaddress
            if ( !((Constants.HOSTNAME_TOKEN.equals(item)) || 
                   (Constants.IPADDRESS_TOKEN.equals(item))) )
                keyList.add(item);
         }
         Collections.sort(keyList);
         
         if (keyList.isEmpty())
         {
            MQFM.logger.info("     <None>");
         }
         else
         {
            Enumeration<String> names = keyList.elements();
            
            while (names.hasMoreElements())
            {
               String name = names.nextElement();
               MQFM.logger.info("     "+StringUtilities.padRight(name, " ", 21)+ "= " + userProperties.get(name));
            }
         }
      }
   }
}
