package biz.capitalware.mqfm.watch;

import java.util.ArrayList;

import biz.capitalware.mqfm.action.objects.SendObject;
import biz.capitalware.mqfm.mq.objects.MQObject;

/**
 * Abstract Class: FileWatch and DirectoryWatch are extended from this base.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public abstract class Watch
{
   protected String        _completePathToTarget;
   protected SendObject    _so;
   protected MQObject      _mq;

   /**
    * Initialize Watch
    *
    * @param filename
    *           filename of file or directory to watch
    */
   public Watch(String data)
   {
      this._completePathToTarget = data;
   }

   /**
    * Retrieve the send object
    * @return
    */
   public SendObject getSendObject()
   {
      return _so;
   }

   /**
    * Set the basic object value
    * @param bo
    */
   public void setSendObject(SendObject so)
   {
      _so = so;
   }

   /**
    * Retrieve the MQ object
    * @return
    */
   public MQObject getMQObject()
   {
      return _mq;
   }

   /**
    * Set the MQ object
    * @param mq
    */
   public void setMQObject(MQObject mq)
   {
      _mq = mq;
   }

   /**
    * @return path of this watch
    */
   public String getPath()
   {
      return _completePathToTarget;
   }

   /**
    * @return ArrayList representation of changes of this watch
    */
   public abstract ArrayList<String> check();

   /**
    * Output values used.
    */
   public abstract void printValues();

   /**
    * Reset the last modified time stamp
    */
   public abstract void resetLastModified(String filename);
}