package biz.capitalware.mqfm.xml;

import java.io.*;

import org.jdom.*;
import org.jdom.input.*;

import biz.capitalware.mqfm.objects.Constants;

/**
 * This class handles the reading and parsing of Job XML file and parse parameters
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class EmbeddedMsgXml extends FMXml
{
   private String    _jobFile = null;
   private String    _directory = null;
   private String    _filename = null;

   /**
    * The constructor
    * @param logger
    */
   public EmbeddedMsgXml()
   {
      super();
   }

   /**
    * Read Job XML file and set parameters
    *
    * @param xmlFilename
    *           Filename of job.xml file
    * @throws IOException
    */
   public void readXMLFile(byte[] xmlByteData) throws JDOMException, IOException
   {
      SAXBuilder builder = new SAXBuilder(false);
      InputStream is = new ByteArrayInputStream(xmlByteData);
      Document doc = builder.build(is);
      Element rootElement = doc.getRootElement();
      // get main element
      Element remoteElement = rootElement.getChild(Constants.REMOTE_ELEMENT);

      if ( remoteElement.getChild(Constants.EXECUTE_ELEMENT) != null)
      {
         Element execElement = remoteElement.getChild(Constants.EXECUTE_ELEMENT);
         if (execElement.getAttribute(Constants.XML_FILE_ATTRIBUTE) != null)
            _jobFile = execElement.getAttribute(Constants.XML_FILE_ATTRIBUTE).getValue();
      }

      if ( remoteElement.getChild(Constants.DIRECTORY_ELEMENT) != null)
         _directory = remoteElement.getChild(Constants.DIRECTORY_ELEMENT).getTextTrim();

      if ( remoteElement.getChild(Constants.FILE_ELEMENT) != null)
         _filename = remoteElement.getChild(Constants.FILE_ELEMENT).getTextTrim();
   }

   /**
    * Not used.
    */
   public void readXMLFile(String xmlFilename) throws JDOMException,IOException
   {
   }

   /**
    * Retrieve the job file
    * @return jobFile
    */
   public String getJobFile()
   {
      return _jobFile;
   }

   /**
    * Retrieve the job file
    * @return jobFile
    */
   public String getDirectory()
   {
      return _directory;
   }

   /**
    * Retrieve the job file
    * @return jobFile
    */
   public String getFilename()
   {
      return _filename;
   }
}
