package biz.capitalware.mqfm.xml;

import java.util.*;
import java.io.*;

import org.jdom.*;
import org.jdom.input.*;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;
import biz.capitalware.mqfm.schedule.Schedule;

/**
 * This class handles the reading and parsing of Schedule XML file and parse parameters
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class ScheduleXml extends FMXml
{
   private Schedule[]      _schedules;

   /**
    * The constructor
    * @param logger
    */
   public ScheduleXml()
   {
      super();
   }

   /**
    * Read Schedule XML file and set parameters
    *
    * @param xmlFilename
    *           Filename of test_schedule.xml file
    * @throws IOException
    */
   public void readXMLFile(String xmlFilename) throws JDOMException, IOException
   {
      Schedule so = null;
      Element minuteElement = null;
      Element hourElement = null;
      Element dayOfMonthElement = null;
      Element monthElement = null;
      Element dayOfWeekElement = null;
      Element yearElement = null;
      
      SAXBuilder builder = new SAXBuilder(true);
      Document doc = builder.build(Constants.SCHEDULE_PATH + xmlFilename);
      Element rootElement = doc.getRootElement();
      
      // read and parse schedules
      List scheduleList = rootElement.getChildren(Constants.SCHEDULE_ELEMENT);
      _schedules = new Schedule[scheduleList.size()];
      int si = 0;
      Iterator it = scheduleList.iterator();
      while (it.hasNext())
      {
         Element scheduleElement = (Element) it.next();
         so = new Schedule();

         if (scheduleElement.getAttribute(Constants.XML_FILE_ATTRIBUTE) != null)
            so.xmlFile = scheduleElement.getAttribute(Constants.XML_FILE_ATTRIBUTE).getValue().trim();

         if (so.xmlFile != null)
            so.xmlFile = Tokens.replace(so.xmlFile, MQFM.userProperties);

         if ( (minuteElement = scheduleElement.getChild(Constants.MINUTE_ELEMENT)) != null)
            so.minutes = so.formatStringToInts(minuteElement.getTextTrim());

         if ( (hourElement = scheduleElement.getChild(Constants.HOUR_ELEMENT)) != null)
            so.hours = so.formatStringToInts(hourElement.getTextTrim());

         if ( (dayOfMonthElement = scheduleElement.getChild(Constants.DAYOFMONTH_ELEMENT)) != null)
            so.daysOfMonth = so.formatStringToInts(dayOfMonthElement.getTextTrim());

         if ( (monthElement = scheduleElement.getChild(Constants.MONTH_ELEMENT)) != null)
            so.months = so.formatMonthToInts(monthElement.getTextTrim());

         if ( (dayOfWeekElement = scheduleElement.getChild(Constants.DAYOFWEEK_ELEMENT)) != null)
            so.daysOfWeek = so.formatDayOfWeekToInts(dayOfWeekElement.getTextTrim());
         
         if ( (yearElement = scheduleElement.getChild(Constants.YEAR_ELEMENT)) != null)
            so.year = so.formatStringToInt(yearElement.getTextTrim());
         
         _schedules[si++] = so;
      }
   }

   /**
    * Retrieve an array of schedules.
    * @return schedule
    */
   public Schedule[] getSchedules()
   {
      return _schedules;
   }
}
